django-styleguide
=================

styleguide for django

[http://www.andrefarzat.com/django-styleguide](http://www.andrefarzat.com/django-styleguide)


branch     | Build Status | Coverage Status | Requirements Status
-----------| -------------| ----------------| -------------------
master     | [![Build Status](https://travis-ci.org/andrefarzat/django-styleguide.png?branch=master)](https://travis-ci.org/andrefarzat/django-styleguide) | [![Coverage Status](https://coveralls.io/repos/andrefarzat/django-styleguide/badge.png?branch=master)](https://coveralls.io/r/andrefarzat/django-styleguide?branch=master) | [![Requirements Status](https://requires.io/github/andrefarzat/django-styleguide/requirements.png?branch=master)](https://requires.io/github/andrefarzat/django-styleguide/requirements/?branch=master)
django 1.7 | [![Build Status](https://travis-ci.org/andrefarzat/django-styleguide.png?branch=django1.7)](https://github.com/andrefarzat/django-styleguide/tree/django1.7) | [![Coverage Status](https://coveralls.io/repos/andrefarzat/django-styleguide/badge.png?branch=django1.7)](https://coveralls.io/r/andrefarzat/django-styleguide?branch=django1.7) | [![Requirements Status](https://requires.io/github/andrefarzat/django-styleguide/requirements.png?branch=django1.7)](https://requires.io/github/andrefarzat/django-styleguide/requirements/?branch=django1.7)


Executing the tests
-------------------

1. `pip install -r requirements-dev.txt`
1. `python manage.py test`
1. Drink a coke